<?php
// We have now ensured that we are running the minimum PHP version.
defined('ABSPATH') or die('No script kiddies please!'); // Avoid direct file request

// Check minimum WordPress version
global $wp_version;
if (version_compare($wp_version, RML_MIN_WP, '>=')) {
    $load_core = false;

    // Check minimum WordPress REST API
    if (version_compare($wp_version, '4.7.0', '>=')) {
        $load_core = true;
    } else {
        // Check WP REST API plugin is active
        require_once ABSPATH . 'wp-admin/includes/plugin.php';
        $load_core = is_plugin_active('rest-api/plugin.php');
    }

    // Load core
    if ($load_core) {
        /**
         * Autoloader for lite classes.
         *
         * @param string $className
         */
        function rml_lite_autoload($className) {
            $namespace = RML_NS . '\\';
            if (0 === strpos($className, $namespace)) {
                $name = substr($className, strlen($namespace));
                $basepath = str_replace('\\', '/', $name);

                if (substr($basepath, 0, 5) === 'lite/') {
                    $basepath = preg_replace('/^lite\//', '', $basepath, 1);
                    $filename = RML_OVERRIDES_INC . $basepath . '.php';

                    if (file_exists($filename)) {
                        require_once $filename;
                        return;
                    }

                    error_log($basepath . ': ' . $filename);
                }
            }
        }
        spl_autoload_register('rml_lite_autoload');

        // Composer autoload
        $composer_path = path_join(RML_PATH, 'vendor/autoload.php');
        if (file_exists($composer_path)) {
            require_once $composer_path;
        }

        // Dependents autoload
        $depAutoloaders = glob(path_join(RML_PATH, 'vendor/' . RML_ROOT_SLUG . '/*/vendor/autoload.php'));
        foreach ($depAutoloaders as $composer_path) {
            require_once $composer_path;
        }

        require_once RML_INC . 'Core.php';
        call_user_func(array(RML_NS . '\\Core', 'getInstance'));
    } else {
        // WP REST API version not reached
        require_once RML_INC . 'base/others/fallback-rest-api.php';
    }
} else {
    // Min WP version not reached
    require_once RML_INC . 'base/others/fallback-wp-version.php';
}
